==> mastercard_spendcontrols-1.0.1.tar.gz: mastercard_spendcontrols-1.0.1/mastercardspendcontrols/channel.py <==
#
# Copyright (c) 2016 MasterCard International Incorporated
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without modification, are
# permitted provided that the following conditions are met:
#
# Redistributions of source code must retain the above copyright notice, this list of
# conditions and the following disclaimer.
# Redistributions in binary form must reproduce the above copyright notice, this list of
# conditions and the following disclaimer in the documentation and/or other materials
# provided with the distribution.
# Neither the name of the MasterCard International Incorporated nor the names of its
# contributors may be used to endorse or promote products derived from this software
# without specific prior written permission.
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
# EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
# OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT
# SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
# TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
# OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
# IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
# IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
# SUCH DAMAGE.
#


from mastercardapicore import BaseObject
from mastercardapicore import RequestMap
from mastercardapicore import OperationConfig
from mastercardapicore import OperationMetadata
from resourceconfig import ResourceConfig

class Channel(BaseObject):
	"""
	
	"""

	__config = {
		
		"41667d9b-c983-4554-bc0f-a44d63814428" : OperationConfig("/issuer/spendcontrols/v1/card/{uuid}/controls/alerts/channels", "delete", [], []),
		
		"abdfd9cb-b126-44a8-94bf-81609760eb74" : OperationConfig("/issuer/spendcontrols/v1/card/{uuid}/controls/alerts/channels", "query", [], []),
		
		"dd4e5b4f-92e0-4422-a11b-9941a7f4c2ce" : OperationConfig("/issuer/spendcontrols/v1/card/{uuid}/controls/alerts/channels", "create", [], []),
		
	}

	def getOperationConfig(self,operationUUID):
		if operationUUID not in self.__config:
			raise Exception("Invalid operationUUID: "+operationUUI)

		return self.__config[operationUUID]

	def getOperationMetadata(self):
		return OperationMetadata(ResourceConfig.getInstance().getVersion(), ResourceConfig.getInstance().getHost(), ResourceConfig.getInstance().getContext())





	@classmethod
	def deleteById(cls,id,map=None):
		"""
		Delete object of type Channel by id

		@param str id
		@return Channel of the response of the deleted instance.
		@raise ApiException: raised an exception from the response status
		"""

		mapObj =  RequestMap()
		if id:
			mapObj.set("id", id)

		if map:
			if (isinstance(map,RequestMap)):
				mapObj.setAll(map.getObject())
			else:
				mapObj.setAll(map)

		return BaseObject.execute("41667d9b-c983-4554-bc0f-a44d63814428", Channel(mapObj))

	def delete(self):
		"""
		Delete object of type Channel

		@return Channel of the response of the deleted instance.
		@raise ApiException: raised an exception from the response status
		"""
		return BaseObject.execute("41667d9b-c983-4554-bc0f-a44d63814428", self)








	@classmethod
	def query(cls,criteria):
		"""
		Query objects of type Channel by id and optional criteria
		@param type criteria
		@return Channel object representing the response.
		@raise ApiException: raised an exception from the response status
		"""

		return BaseObject.execute("abdfd9cb-b126-44a8-94bf-81609760eb74", Channel(criteria))

	@classmethod
	def create(cls,mapObj):
		"""
		Creates object of type Channel

		@param Dict mapObj, containing the required parameters to create a new object
		@return Channel of the response of created instance.
		@raise ApiException: raised an exception from the response status
		"""
		return BaseObject.execute("dd4e5b4f-92e0-4422-a11b-9941a7f4c2ce", Channel(mapObj))

==> mastercard_spendcontrols-1.0.2.tar.gz: mastercard_spendcontrols-1.0.2/mastercardspendcontrols/channel.py <==
#
# Copyright (c) 2016 MasterCard International Incorporated
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without modification, are
# permitted provided that the following conditions are met:
#
# Redistributions of source code must retain the above copyright notice, this list of
# conditions and the following disclaimer.
# Redistributions in binary form must reproduce the above copyright notice, this list of
# conditions and the following disclaimer in the documentation and/or other materials
# provided with the distribution.
# Neither the name of the MasterCard International Incorporated nor the names of its
# contributors may be used to endorse or promote products derived from this software
# without specific prior written permission.
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
# EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
# OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT
# SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
# TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
# OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
# IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
# IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
# SUCH DAMAGE.
#


from mastercardapicore import BaseObject
from mastercardapicore import RequestMap
from mastercardapicore import OperationConfig
from mastercardapicore import OperationMetadata
from resourceconfig import ResourceConfig

class Channel(BaseObject):
	"""
	
	"""

	__config = {
		
		"bb5a017d-8415-411c-8dd6-892b641b381a" : OperationConfig("/issuer/spendcontrols/v1/card/{uuid}/controls/alerts/channels", "delete", [], []),
		
		"d7034096-afaf-48e0-b6dd-334816822058" : OperationConfig("/issuer/spendcontrols/v1/card/{uuid}/controls/alerts/channels", "query", [], []),
		
		"781d4400-bd28-43a1-9561-48fb66009250" : OperationConfig("/issuer/spendcontrols/v1/card/{uuid}/controls/alerts/channels", "create", [], []),
		
	}

	def getOperationConfig(self,operationUUID):
		if operationUUID not in self.__config:
			raise Exception("Invalid operationUUID: "+operationUUI)

		return self.__config[operationUUID]

	def getOperationMetadata(self):
		return OperationMetadata(ResourceConfig.getInstance().getVersion(), ResourceConfig.getInstance().getHost(), ResourceConfig.getInstance().getContext())





	@classmethod
	def deleteById(cls,id,map=None):
		"""
		Delete object of type Channel by id

		@param str id
		@return Channel of the response of the deleted instance.
		@raise ApiException: raised an exception from the response status
		"""

		mapObj =  RequestMap()
		if id:
			mapObj.set("id", id)

		if map:
			if (isinstance(map,RequestMap)):
				mapObj.setAll(map.getObject())
			else:
				mapObj.setAll(map)

		return BaseObject.execute("bb5a017d-8415-411c-8dd6-892b641b381a", Channel(mapObj))

	def delete(self):
		"""
		Delete object of type Channel

		@return Channel of the response of the deleted instance.
		@raise ApiException: raised an exception from the response status
		"""
		return BaseObject.execute("bb5a017d-8415-411c-8dd6-892b641b381a", self)








	@classmethod
	def query(cls,criteria):
		"""
		Query objects of type Channel by id and optional criteria
		@param type criteria
		@return Channel object representing the response.
		@raise ApiException: raised an exception from the response status
		"""

		return BaseObject.execute("d7034096-afaf-48e0-b6dd-334816822058", Channel(criteria))

	@classmethod
	def create(cls,mapObj):
		"""
		Creates object of type Channel

		@param Dict mapObj, containing the required parameters to create a new object
		@return Channel of the response of created instance.
		@raise ApiException: raised an exception from the response status
		"""
		return BaseObject.execute("781d4400-bd28-43a1-9561-48fb66009250", Channel(mapObj))
